@@ -45,7 +45,6 @@ import logging
 import threading
 
 from . import util
-from . import async
 from . import common
 from . import legacy
 from . import typesf
@@ -233,26 +232,6 @@ def patch(
         **kwargs
     )
 
-def get_a(*args, **kwargs):
-    kwargs["async"] = True
-    for value in async.to_coroutine(get, *args, **kwargs): yield value
-
-def post_a(*args, **kwargs):
-    kwargs["async"] = True
-    for value in async.to_coroutine(post, *args, **kwargs): yield value
-
-def put_a(*args, **kwargs):
-    kwargs["async"] = True
-    for value in async.to_coroutine(put, *args, **kwargs): yield value
-
-def delete_a(*args, **kwargs):
-    kwargs["async"] = True
-    for value in async.to_coroutine(delete, *args, **kwargs): yield value
-
-def patch_a(*args, **kwargs):
-    kwargs["async"] = True
-    for value in async.to_coroutine(patch, *args, **kwargs): yield value
-
 def _method(method, *args, **kwargs):
     try:
         auth_callback = kwargs.pop("auth_callback", None)
@@ -514,7 +493,7 @@ def _method_payload(
     if authorization: headers["Authorization"] = "Basic %s" % authorization
     url = str(url)
 
-    _method_callback(handle, **kwargs)
+    _method_callback(handle, kwargs)
     file = _resolve(url, name, headers, data, silent, timeout, **kwargs)
     if file == None: return file
 
@@ -625,7 +604,7 @@ def _resolve_legacy(url, method, headers, data, silent, timeout, **kwargs):
     return opener.open(request, timeout = timeout)
 
 def _resolve_requests(url, method, headers, data, silent, timeout, **kwargs):
-    util.import_pip("requests")
+    util.ensure_pip("requests")
     import requests
     global _requests_session
 
@@ -680,7 +659,7 @@ def _resolve_requests(url, method, headers, data, silent, timeout, **kwargs):
     return response
 
 def _resolve_netius(url, method, headers, data, silent, timeout, **kwargs):
-    util.import_pip("netius")
+    util.ensure_pip("netius")
     import netius.clients
 
     # determines the final value of the silent flag taking into
