@@ -871,6 +871,72 @@ class Model(legacy.with_meta(meta.Ordered, observer.Observable)):
         operations_m = cls.operations_m()
         return operations_m.get(name, None)
 
+    @classmethod
+    def views(cls):
+        # in case the views are already "cached" in the current
+        # class (fast retrieval) returns immediately
+        if "_views" in cls.__dict__: return cls._views
+
+        # creates the list that will hold the complete set of method
+        # names for views type methods
+        views = []
+
+        # retrieves the complete set of method names for the current
+        # class this is going to be used to determine the ones that
+        # are considered to be view oriented
+        methods = cls.methods()
+
+        # iterates over the complete set of method names for the current
+        # class hierarchy to determine the ones that are views
+        for name in methods:
+            method = getattr(cls, name)
+            if not hasattr(method, "_view"): continue
+            reference = hasattr(method, "__self__") and method.__self__
+            is_instance = False if reference else True
+            method._view["instance"] = is_instance
+            views.append(method._view)
+
+        # sorts the various views taking into account the name of
+        # the view, this is considered the pre-defined order
+        views.sort(key = lambda item: item["name"])
+
+        # saves the list of view method names defined under the current
+        # class and then returns the contents of it to the caller method
+        cls._views = views
+        return views
+
+    @classmethod
+    def views_m(cls):
+        # in case the views are already "cached" in the current
+        # class (fast retrieval) returns immediately
+        if "_views_m" in cls.__dict__: return cls._views_m
+
+        # creates the map that will hold the complete set of method
+        # names for views type methods
+        views_m = dict()
+
+        # retrieves the complete set of method names for the current
+        # class this is going to be used to determine the ones that
+        # are considered to be view oriented
+        methods = cls.methods()
+
+        # iterates over the complete set of method names for the current
+        # class hierarchy to determine the ones that are views
+        for name in methods:
+            method = getattr(cls, name)
+            if not hasattr(method, "_view"): continue
+            views_m[method.__name__] = method._view
+
+        # saves the map of view method names defined under the current
+        # class and then returns the contents of it to the caller method
+        cls._views_m = views_m
+        return views_m
+
+    @classmethod
+    def view(cls, name):
+        views_m = cls.views_m()
+        return views_m.get(name, None)
+
     @classmethod
     def definition_n(cls, name):
         definition = cls.definition()
@@ -2353,6 +2419,15 @@ class Operation(Action):
 
     pass
 
+class View(Action):
+    """
+    Definition associated with a model that represents
+    the information to be used for the display of associated
+    set of elements/items of a model.
+    """
+
+    pass
+
 def link(name = None, parameters = (), devel = False):
     """
     Decorator function to be used to "annotate" the provided
@@ -2437,4 +2512,43 @@ def operation(
 
     return decorator
 
+def view(
+    name = None,
+    parameters = (),
+    devel = False
+):
+    """
+    Decorator function to be used to "annotate" the provided
+    function as an view that is able to return a set of configurations
+    for the proper display of associated information.
+
+    Proper usage of the view definition/decoration is context
+    based and should vary based on application.
+
+    :type name: String
+    :param name: The name of the view (in plain english)
+    so that a better user experience is possible.
+    :type parameters: Tuple
+    :param parameters: The sequence containing tuples that describe
+    the various parameters to be send to the view.
+    :type devel: bool
+    :param devel: If the view should only be used/available under
+    development like environments (eg: debugging purposes).
+    :rtype: Function
+    :return: The decorator function that is going to be used to
+    generated the final function to be called.
+    """
+
+    def decorator(function, *args, **kwargs):
+        function._view = View(
+            method = function.__name__,
+            name = name or function.__name__,
+            parameters = parameters,
+            devel = devel
+        )
+
+        return function
+
+    return decorator
+
 field = Field
