@@ -133,9 +133,19 @@ def dumps(*args):
 
 def serialize(obj):
     if isinstance(obj, common.model().Model): return obj.model
-    if isinstance(obj, typesf.Type): return obj.json_v()
+    if isinstance(obj, typesf.AbstractType): return obj.json_v()
     return bson.json_util.default(obj)
 
+def directions(all = False):
+    return (
+        pymongo.ASCENDING,
+        pymongo.DESCENDING,
+        pymongo.HASHED
+    ) if all else (
+        pymongo.ASCENDING,
+        pymongo.DESCENDING
+    )
+
 def is_mongo(obj):
     if bson and isinstance(obj, bson.ObjectId): return True
     if bson and isinstance(obj, bson.DBRef): return True
@@ -161,5 +171,15 @@ def _store_remove(store, *args, **kwargs):
     else: store.remove(*args, **kwargs)
 
 def _store_ensure_index(store, *args, **kwargs):
+    kwargs["background"] = kwargs.get("background", True)
     if is_new(): store.create_index(*args, **kwargs)
     else: store.ensure_index(*args, **kwargs)
+
+def _store_ensure_index_many(store, *args, **kwargs):
+    directions_l = kwargs.pop("directions", None)
+    if directions_l == "all": directions_l = directions(all = True)
+    elif directions_l == None: directions_l = directions()
+    for direction in directions_l:
+        _args = list(args)
+        _args[0] = [(_args[0], direction)]
+        _store_ensure_index(store, *_args, **kwargs)
