@@ -611,7 +611,7 @@ class Request(object):
 
         # tries to retrieve the session reference for the
         # provided sid (session id) in case there's an exception
-        # defaults to unset session so that a new gets created
+        # defaults to unset session so that a new one gets created
         try: session = self.session_c.get_s(sid, request = self)
         except: session = None
 
@@ -697,8 +697,8 @@ class MockRequest(Request):
     the logic being running outside of web request.
     """
 
-    def __init__(self, locale = "en_us"):
-        Request.__init__(self, "NONE", "/")
+    def __init__(self, locale = "en_us", *args, **kwargs):
+        Request.__init__(self, *args, **kwargs)
         self.locale = locale
         self.files_s = dict()
         self.post_s = dict()
