@@ -203,3 +203,63 @@ class BaseTest(unittest.TestCase):
         result = self.app.slugify_slugier(appier.legacy.bytes("你好世界", encoding = "utf-8"))
         self.assertEqual(type(result), str)
         self.assertEqual(result, "%e4%bd%a0%e5%a5%bd%e4%b8%96%e7%95%8c")
+
+    def test_url_for(self):
+        result = self.app.url_for("app.login")
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "/login")
+
+        result = self.app.url_for("app.login", query = "query_string")
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "/login?query_string")
+
+        result = self.app.url_for("app.login", params = dict(query = "query_string"))
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "/login?query=query_string")
+
+        result = self.app.url_for("static", filename = "hello.txt")
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "/static/hello.txt")
+
+        result = self.app.url_for("static", filename = "hello.txt", compress = "gzip")
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "/static/hello.txt?compress=gzip")
+
+    def test_filters(self):
+        if not self.app.jinja:
+            if not hasattr(self, "skipTest"): return
+            self.skipTest("No jinja template engine present")
+
+        template = appier.Template("{{ message|locale }}")
+        result = self.app.template(template, message = "hello")
+        self.assertEqual(result, "hello")
+
+        template = appier.Template("{{ message|nl_to_br }}")
+        result = self.app.template(template, message = "hello\n")
+        self.assertEqual(result, "hello<br/>\n")
+
+        template = appier.Template("{{ message|sp_to_nbsp }}")
+        result = self.app.template(template, message = "hello world")
+        self.assertEqual(result, "hello&nbsp;world")
+
+    def test_locale_filter(self):
+        if not self.app.jinja:
+            if not hasattr(self, "skipTest"): return
+            self.skipTest("No jinja template engine present")
+
+        self.app._register_bundle({
+            "hello" : appier.legacy.u("olá"),
+            "world" : appier.legacy.u("mundo"),
+        }, "pt_pt")
+
+        template = appier.Template("{{ message|locale }}")
+        result = self.app.template(template, locale = "pt_pt", message = "hello")
+        self.assertEqual(result, appier.legacy.u("olá"))
+        result = self.app.template(template, locale = "en_us", message = "hello")
+        self.assertEqual(result, appier.legacy.u("hello"))
+
+        template = appier.Template("{{ 'hello'|locale }}")
+        result = self.app.template(template, locale = "pt_pt")
+        self.assertEqual(result, appier.legacy.u("olá"))
+        result = self.app.template(template, locale = "en_us")
+        self.assertEqual(result, appier.legacy.u("hello"))
