@@ -328,7 +328,7 @@ class ImageFile(File):
         File.build_i(self, file)
         self.width = file.width if hasattr(file, "width") else 0
         self.height = file.height if hasattr(file, "height") else 0
-        self.format = file.height if hasattr(file, "format") else None
+        self.format = file.format if hasattr(file, "format") else None
         self._ensure_all()
 
     def build_f(self, file):
@@ -364,9 +364,12 @@ class ImageFile(File):
         except: return self._size_default()
 
     def _size_image(self):
+        if self.data: return self._size_pil()
+        else: return self._size_default()
+
+    def _size_pil(self):
         util.ensure_pip("PIL", package = "pillow")
         import PIL.Image
-        if not self.data: return self._size_default()
         buffer = legacy.BytesIO(self.data)
         try:
             image = PIL.Image.open(buffer)
@@ -383,9 +386,12 @@ class ImageFile(File):
         except: return self._mime_default()
 
     def _mime_image(self):
+        if self.data: return self._mime_pil()
+        else: return self._mime_default()
+
+    def _mime_pil(self):
         util.ensure_pip("PIL", package = "pillow")
         import PIL.Image
-        if not self.data: return self._size_default()
         buffer = legacy.BytesIO(self.data)
         try:
             image = PIL.Image.open(buffer)
@@ -410,6 +416,14 @@ def image(width = None, height = None, format = "png"):
         def build_b64(self, file_m):
             ImageFile.build_b64(self, file_m)
 
+            # verifies if there's valid data in the current file
+            # if that's not the case there's nothing remaining to
+            # be done (not going to process the file)
+            if not self.data_b64: return
+
+            # determines if a resize operation is required for the
+            # current image data, if that's not the case returns the
+            # control flow immediately (nothing to be done)
             need_resize = self.need_resize(
                 width_o = self.width,
                 height_o = self.height,
@@ -417,6 +431,9 @@ def image(width = None, height = None, format = "png"):
             )
             if not need_resize: return
 
+            # decodes the base 64 based data and then runs the resize
+            # operation with the current data re-encoding it back to
+            # the base 64 model to be used in the map storage
             data_b64 = legacy.bytes(self.data_b64)
             data = base64.b64decode(data_b64)
             data = self.resize(data)
@@ -432,22 +449,31 @@ def image(width = None, height = None, format = "png"):
             # removes a series of keys from the file map as
             # they are no longer reliable and may reflect
             # different values from the ones contained in data
-            # theses should be update b y the "ensure" methods
+            # theses should be update by the "ensure" methods
             for name in ("width", "height", "format"):
                 if name in file_m: del file_m[name]
 
             ImageFile.build_b64(self, file_m)
 
         def build_t(self, file_t):
+            # unpacks the file tuple into its component to be
+            # used for the format and size ensure operations
             name, content_type, data = file_t
-            try: _data = self.resize(data)
+
+            # tries to run the resize operation to ensure that
+            # the proper size and format is present in the data
+            try: _data = self.resize(data) if data else data
             except: _data = data
+
+            # creates the "new" file tuple with the newly resized
+            # image data and runs the parent tuple build method
             file_t = (name, content_type, _data)
             ImageFile.build_t(self, file_t)
 
         def resize(self, data = None):
             util.ensure_pip("PIL", package = "pillow")
             import PIL.Image
+
             data = data or self.data
             if not data: return data
 
